credentials = {
    "pytest":{
        # This is a test user and should not be used anywhere else
        # password is stored in bitwarden "daves_utilities - pytest"
        "usr": 'david_pytest',
        "pwd": (
            b'gAAAAABmJ7g8NDtWLZ1Pw4S68krPteAYDRk4ZcRYiOSEWo8h9HZmLp6VejU7qbi6asv8CF'
            b'Kwnl5gOirOWeg5gwmkFcOmKC5Zlq7vE4-rTg4iBsyPssAu9Eg='
        )
    },
    "postgres":{
        # password is stored in bitwarden "daves_utilities - postgres"
        "usr": 'david_postgres',
        "pwd": (
            b'gAAAAABmJr3YNnZGzXTTqLvaDgCGz-AoY93XoqeZbXjcRzHLOkPXGmQP5ucccFjVFjTwmqj'
            b'Z0UOl605cGGrvDCBfO2rm7qB9tAlHSEGZqfYjib2glzGSNz0='
        )
    },
    "fastapi":{
        # password is stored in bitwarden "daves_utilities - fastapi"
        "usr": 'david_fastapi',
        "pwd": (
            b'gAAAAABmJr5XjnJBx0MtbGkgnKEQdgYR_LZKIuC1BnywXaMGXsXCpSlqukdHu4z6dcANSf6'
            b'K3pBJsacF01WQj_6ykile6juE0J0vu9MNV08SBJN0dwtpVcY='
        )
    },
}
